@@ -17,7 +17,7 @@
 #    along with Treep.  If not, see <https://www.gnu.org/licenses/>.
 
 import os
-import treep_git
+from . import treep_git
 
 # return a status for each repo find under all folders contained in path
 
