@@ -28,7 +28,8 @@ class Repository(object):
                   path,
                   branch="master",
                   commit=None,
-                  tag=None ) :
+                  tag=None,
+                  compilation=None) :
 
         if path is None:
             path = ''
@@ -39,5 +40,6 @@ class Repository(object):
         self.branch = branch
         self.commit = commit
         self.tag = tag
+        self.compilation = compilation
 
 
