@@ -19,16 +19,24 @@
 
 from __future__ import print_function
 
-import git,sys,os,time
+import git,sys,os,time,multiprocessing
 
 from .status import Status
 
 from .process_calls import execute
 
 
-def clone(url,destination_path):
-    git.Repo.clone_from(url,destination_path)    
+def clone(url,destination_path,submodules=True):
+    git.Repo.clone_from(url,destination_path)
 
+def clone_submodules(path):
+    os.chdir(path)
+    nb_cpus = multiprocessing.cpu_count()
+    nb_cpus -= 1
+    if nb_cpus <= 0 :
+        nb_cpus=1
+    execute("git submodule update --init --recursive")
+    
 def current_branch(path):
     repo = git.Repo.init(path)
     return str(repo.active_branch)
@@ -42,7 +50,11 @@ def list_branches(path):
         if "->" in line:
             return _extract_branch_name(line[line.rfind("->") + 2:])
         try:
-            line = line[line.rfind("/") + 1:]
+            # assumes remotes/origin/branch_name
+            # removing 'remotes'
+            line = line[line.find("/")+1:]
+            # removing 'origin'
+            line = line[line.find("/")+1:]
         except BaseException:
             pass
         line = line.replace("*", "")
@@ -124,8 +136,32 @@ def add_all(path):
     repo = git.Repo.init(path)
     nb_staged_files = len(repo.index.diff("HEAD"))
     return nb_staged_files
-    
-    
+
+
+# note: returns None if invalid origin,
+#       because "git remote show origin"
+#       outputs valid result only for valid URL
+def _get_origin(path,pattern):
+    os.chdir(path)
+    out = execute("git remote show origin")
+    lines = out.split("\n")
+    for line in lines:
+        if pattern in line and "URL:" in line:
+            return line[line.index("URL:")+4:]
+
+
+def get_fetch_origin(path):
+    return _get_origin(path,"Fetch")
+
+
+def get_push_origin(path):
+    return _get_origin(path,"Push")
+
+
+def set_origin(path,origin):
+    os.chdir(path)
+    out = execute("git remote set-url origin "+origin)
+
 def commit(path,message):
     repo = git.Repo.init(path)
     repo.index.commit(str(message))
@@ -139,10 +175,20 @@ def pull(path):
 def local_modifications(path):
     git_status = status_message(path)
     repo = git.Repo(path=path)
-    if repo.untracked_files or ("up-to-date" not in git_status) or ("clean" not in git_status):
+    if repo.untracked_files:
+        return True
+    if ("up-to-date" not in git_status) or ("clean" not in git_status):
         return True
     return False
 
+
+def get_url(path, remote='origin'):
+    try :
+        repo = git.Repo(path=path)
+    except :
+        return None
+    return repo.remote(name=remote).url
+
     
 def get_status(path):
 
@@ -189,8 +235,10 @@ def get_status(path):
     if local_modifications(path):
         status.local_modifications = True
         try:
-                                       # local modif                # staged files
-            status.nb_modified_files = len(repo.index.diff(None)) + len(repo.index.diff("HEAD")) 
+                                       
+            status.nb_modified_files = len(repo.index.diff(None)) # local modif
+            status.nb_modified_files += len(repo.index.diff("HEAD")) # staged files
+            status.nb_modified_files += len(repo.untracked_files) # untracked files 
         except :
             # happens on empty repositories
             status.nb_modified_files = 0
